import React, { Component } from 'react'
// import PropTypes from 'prop-types'

/**
 * A React component for the font-awesome icon library.
 *
 * @param {String} [ariaLabel] An extra accessibility label to put on the icon
 * @param {Boolean} [border=false] Whether or not to show a border radius
 * @param {String} [className] An extra set of CSS classes to add to the component
 * @param {Object} [cssModule] Option to pass FontAwesome CSS as a module
 * @module FontAwesome
 * @type {ReactClass}
 */
class FocusElement extends Component {
  constructor(props) {
    super(props)
  }

  handle(event) {
    let userSelection;
    if (window.getSelection) {
        userSelection = window.getSelection();
    } else if (document.selection) {
        userSelection = document.selection.createRange();
    };
    let content = event.target.firstChild;
    if (content) {
      let range = document.createRange();
      range.selectNode(content);
      range.setStart(content, content.length);
      range.setEnd(content, content.length);
      userSelection.removeAllRanges();
      userSelection.addRange(range);
      userSelection.extend(content, content.length);
      userSelection.collapseToEnd();
    } else {
      event.target.focus();
    };
  }

  render() {
      let self = this;
      setTimeout(() => {
        self.refs.focus.setAttribute("contenteditable", true);
      }, 0);
      return (
        <div {...this.props} ref="focus" onClick={this.handle.bind(this)}></div>
      );
  }
}

// FocusElement.propTypes = {
//   ariaLabel: PropTypes.string,
//   border: PropTypes.bool,
//   className: PropTypes.string,
//   cssModule: PropTypes.object,
//   fixedWidth: PropTypes.bool,
//   flip: PropTypes.oneOf([ 'horizontal', 'vertical' ]),
//   inverse: PropTypes.bool,
//   name: PropTypes.string.isRequired,
//   pulse: PropTypes.bool,
//   rotate: PropTypes.oneOf([ 90, 180, 270 ]),
//   size: PropTypes.oneOf([ 'lg', '2x', '3x', '4x', '5x' ]),
//   spin: PropTypes.bool,
//   stack: PropTypes.oneOf([ '1x', '2x' ]),
//   tag: PropTypes.string,
// }

export default FocusElement
